Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h

Issue 2111293003: Removed callback between old AudioConferenceMixer and OutputMixer. The audio frame with mixed audio… (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@new_mixer_format
Patch Set: Renamed variables, removed DCHECK(false), changed back copyright years. Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h
diff --git a/webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h b/webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h
index f6916409536d5a86e459255f7afcf41122efb7e6..6a6bf1ea75ab5bda6a9b936c0362b166b20db547 100644
--- a/webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h
+++ b/webrtc/modules/audio_mixer/include/new_audio_conference_mixer.h
@@ -16,13 +16,11 @@
#include "webrtc/modules/include/module_common_types.h"
namespace webrtc {
-class OldAudioMixerOutputReceiver;
class MixerAudioSource;
-class Trace;
class NewAudioConferenceMixer : public Module {
public:
- enum { kMaximumAmountOfMixedParticipants = 3 };
+ enum { kMaximumAmountOfMixedAudioSources = 3 };
enum Frequency {
kNbInHz = 8000,
kWbInHz = 16000,
@@ -40,32 +38,32 @@ class NewAudioConferenceMixer : public Module {
int64_t TimeUntilNextProcess() override = 0;
void Process() override = 0;
- // Register/unregister a callback class for receiving the mixed audio.
- virtual int32_t RegisterMixedStreamCallback(
- OldAudioMixerOutputReceiver* receiver) = 0;
- virtual int32_t UnRegisterMixedStreamCallback() = 0;
-
- // Add/remove participants as candidates for mixing.
- virtual int32_t SetMixabilityStatus(MixerAudioSource* participant,
+ // Add/remove audio sources as candidates for mixing.
+ virtual int32_t SetMixabilityStatus(MixerAudioSource* audio_source,
bool mixable) = 0;
- // Returns true if a participant is a candidate for mixing.
- virtual bool MixabilityStatus(const MixerAudioSource& participant) const = 0;
+ // Returns true if an audio source is a candidate for mixing.
+ virtual bool MixabilityStatus(const MixerAudioSource& audio_source) const = 0;
- // Inform the mixer that the participant should always be mixed and not
- // count toward the number of mixed participants. Note that a participant
+ // Inform the mixer that the audio source should always be mixed and not
+ // count toward the number of mixed audio sources. Note that an audio source
// must have been added to the mixer (by calling SetMixabilityStatus())
// before this function can be successfully called.
- virtual int32_t SetAnonymousMixabilityStatus(MixerAudioSource* participant,
+ virtual int32_t SetAnonymousMixabilityStatus(MixerAudioSource* audio_source,
bool mixable) = 0;
- // Returns true if the participant is mixed anonymously.
- virtual bool AnonymousMixabilityStatus(
- const MixerAudioSource& participant) const = 0;
+
+ // Performs mixing by asking registered audio sources for audio.
+ // The mixed result is placed in the provided AudioFrame.
+ virtual void Mix(AudioFrame* audio_frame_for_mixing) = 0;
// Set the minimum sampling frequency at which to mix. The mixing algorithm
// may still choose to mix at a higher samling frequency to avoid
// downsampling of audio contributing to the mixed audio.
virtual int32_t SetMinimumMixingFrequency(Frequency freq) = 0;
+ // Returns true if the audio source is mixed anonymously.
+ virtual bool AnonymousMixabilityStatus(
+ const MixerAudioSource& audio_source) const = 0;
+
protected:
NewAudioConferenceMixer() {}
};

Powered by Google App Engine
This is Rietveld 408576698